@@ -33,7 +33,7 @@
 
 #include "iprop.h"
 
-RCSID("$Id: ipropd_slave.c 22773 2008-03-24 19:13:46Z lha $");
+RCSID("$Id: ipropd_slave.c 23249 2008-06-01 22:36:47Z lha $");
 
 static krb5_log_facility *log_facility;
 static char *server_time_lost = "5 min";
@@ -534,8 +534,10 @@ main(int argc, char **argv)
     server_context = (kadm5_server_context *)kadm_handle;
 
     ret = kadm5_log_init (server_context);
-    if (ret)
+    if (ret) {
+	krb5_clear_error_string(context);
 	krb5_err (context, 1, ret, "kadm5_log_init");
+    }
 
     get_creds(context, keytab_str, &ccache, master);
 
